#include "MyDetectorConstruction.hh"
#include "MyPhysicsList.hh"
#include "MyPrimaryGeneratorAction.hh"
#include "G4RunManager.hh"
#include "G4UIterminal.hh"
#include "G4UItcsh.hh"
#include "G4String.hh"

#ifdef G4VIS_USE
#include "G4VisExecutive.hh"
#endif



#ifdef G4UI_USE
#include "G4UIExecutive.hh"
#endif

int main(int argc,char** argv) {
  
  // Run manager
  G4RunManager * runManager = new G4RunManager;
  
  // Mandatory initialization classes
  runManager->SetUserInitialization(new MyDetectorConstruction);
  runManager->SetUserInitialization(new MyPhysicsList);
    
  // User action classes
  runManager->SetUserAction(new MyPrimaryGeneratorAction());
  
  // Initialize G4 kernel
  runManager->Initialize();
  

    //get the pointer to the User Interface manager 
  G4UImanager* UI = G4UImanager::GetUIpointer();  

  if (argc!=1)   // batch mode  
    {
     G4String command = "/control/execute ";
     G4String fileName = argv[1];
     UI->ApplyCommand(command+fileName);
    }
    
  else           //define visualization and UI terminal for interactive mode
    { 
#ifdef G4VIS_USE
   G4VisManager* visManager = new G4VisExecutive;
   visManager->Initialize();
#endif    
     
#ifdef G4UI_USE
      G4UIExecutive * ui = new G4UIExecutive(argc,argv);    
      
      //UI->ApplyCommand("/control/execute vis.mac"); 
      UI->ApplyCommand("/gui/addIcon \"Open macro file\" open /control/execute");
      //UI->ApplyCommand("/gui/addMenu run Run");
      //UI->ApplyCommand("/gui/addButton run \"beamOn 10\" \"open /run/beamOn 10\"");
      
      ui->SessionStart();
      delete ui;
#endif
     
#ifdef G4VIS_USE
     delete visManager;
#endif     
    }

  //job termination
  //
  delete runManager;

  return 0;
  
  
}

